@@ -41,6 +41,12 @@ class DescribePurchasedApisRequest(RpcRequest):
 	def set_Visibility(self,Visibility):
 		self.add_query_param('Visibility',Visibility)
 
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
 	def get_GroupId(self):
 		return self.get_query_params().get('GroupId')
 
